@@ -2,16 +2,21 @@
 set -eo pipefail
 
 ROOT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")/.." && pwd)"
-LOCK_FILE="$ROOT_DIR/state/master_restart.lock"
-LOG_DIR="$ROOT_DIR/logs"
+MASTER_CONFIG_ROOT="${MASTER_CONFIG_ROOT:-$HOME/.config/vibego}"
+STATE_DIR="$MASTER_CONFIG_ROOT/state"
+LOG_DIR="$MASTER_CONFIG_ROOT/logs"
+LOCK_FILE="$STATE_DIR/master_restart.lock"
 START_LOG="$LOG_DIR/start.log"
-CODEX_STAMP_FILE="$ROOT_DIR/state/npm_codex_install.stamp"
+CODEX_STAMP_FILE="$STATE_DIR/npm_codex_install.stamp"
 CODEX_INSTALL_TTL="${CODEX_INSTALL_TTL:-86400}"
 
 # 统一重启信号文件路径：使用配置目录而非代码目录
 # 这样 pipx 安装的 master 和源码运行的 master 可以共享同一个信号文件
-MASTER_CONFIG_ROOT="${MASTER_CONFIG_ROOT:-$HOME/.config/vibego}"
-export MASTER_RESTART_SIGNAL_PATH="$MASTER_CONFIG_ROOT/state/restart_signal.json"
+export MASTER_RESTART_SIGNAL_PATH="$STATE_DIR/restart_signal.json"
+export LOG_ROOT="${LOG_ROOT:-$LOG_DIR}"
+if [[ -z "${LOG_FILE:-}" ]]; then
+  export LOG_FILE="$LOG_DIR/vibe.log"
+fi
 
 log_line() {
   local ts
@@ -109,7 +114,8 @@ ensure_codex_installed() {
 ensure_codex_installed
 
 select_python_binary() {
-  # 选择满足 CPython <=3.13 的解释器，避免 PyO3 依赖构建失败
+  # 选择满足 CPython <=3.12 的解释器，默认禁用 3.13（pydantic-core 在 pipx 基础环境下无兼容轮子）
+  local allow_py313="${VIBEGO_ALLOW_PY313:-}"
   local candidates=()
   local chosen=""
   local name
@@ -138,6 +144,14 @@ select_python_binary() {
       log_line "跳过 ${name} (版本 ${version_raw})：非 CPython 3.x" >&2
       continue
     fi
+    local explicit_override=0
+    if [[ -n "${VIBEGO_PYTHON:-}" && "$name" == "$VIBEGO_PYTHON" ]]; then
+      explicit_override=1
+    fi
+    if [[ "$minor" =~ ^[0-9]+$ ]] && (( minor == 13 )) && [[ "$allow_py313" != "1" ]] && (( explicit_override == 0 )); then
+      log_line "跳过 ${name} (版本 ${version_raw})：默认禁用 Python 3.13，可设置 VIBEGO_ALLOW_PY313=1 覆盖" >&2
+      continue
+    fi
     if [[ "$minor" =~ ^[0-9]+$ ]] && (( minor > 13 )); then
       log_line "跳过 ${name} (版本 ${version_raw})：高于 3.13" >&2
       continue
@@ -191,7 +205,7 @@ cleanup_old_master() {
   local max_wait=10  # 最多等待10秒优雅退出
   local waited=0
   local old_pids=""
-  local master_pid_file="${MASTER_CONFIG_ROOT:-$HOME/.config/vibego}/state/master.pid"
+  local master_pid_file="$STATE_DIR/master.pid"
 
   # 方案1：优先从 PID 文件读取
   if [[ -f "$master_pid_file" ]]; then
@@ -401,7 +415,7 @@ if ! kill -0 "$MASTER_PID" 2>/dev/null; then
   exit 1
 fi
 
-log_info "master 已后台启动，PID=$MASTER_PID，日志写入 vibe.log"
+log_info "master 已后台启动，PID=$MASTER_PID，日志写入 ${LOG_FILE}"
 
 # 健康检查：等待 master 上线并验证关键 worker
 log_info "开始执行健康检查..."
@@ -417,8 +431,8 @@ else
   log_error "⚠️ master 健康检查失败，耗时 ${HEALTHCHECK_DURATION}s"
   log_error "建议检查："
   log_error "  - 进程状态: ps aux | grep 'python.*master.py'"
-  log_error "  - 启动日志: tail -100 $ROOT_DIR/logs/start.log"
-  log_error "  - 运行日志: tail -100 $ROOT_DIR/vibe.log"
+  log_error "  - 启动日志: tail -100 $LOG_DIR/start.log"
+  log_error "  - 运行日志: tail -100 $LOG_FILE"
   log_error "  - 进程 PID: $MASTER_PID"
 
   # 检查进程是否仍在运行
