@@ -31,6 +31,8 @@ class TaskService:
     """封装任务相关的数据库操作。"""
 
     def __init__(self, db_path: Path, project_slug: str) -> None:
+        """初始化服务实例，绑定数据库路径与项目标识。"""
+
         self.db_path = Path(db_path)
         self.project_slug = project_slug
         self._lock = asyncio.Lock()
@@ -38,6 +40,8 @@ class TaskService:
         self._valid_statuses = set(TASK_STATUSES)
 
     async def initialize(self) -> None:
+        """确保数据库结构存在，并执行必要的迁移逻辑。"""
+
         if self._initialized:
             return
         self.db_path.parent.mkdir(parents=True, exist_ok=True)
@@ -54,6 +58,8 @@ class TaskService:
         self._initialized = True
 
     async def _create_tables(self, db: aiosqlite.Connection) -> None:
+        """创建或补全任务相关的全部表结构与索引。"""
+
         await db.execute(
             """
             CREATE TABLE IF NOT EXISTS tasks (
@@ -366,6 +372,8 @@ class TaskService:
         await db.execute("DROP TABLE IF EXISTS child_sequences")
 
     async def _verify_status_values(self, db: aiosqlite.Connection) -> None:
+        """校验任务表中的状态值是否符合当前合法枚举。"""
+
         async with db.execute(
             "SELECT DISTINCT status FROM tasks WHERE project_slug = ?",
             (self.project_slug,),
@@ -397,6 +405,8 @@ class TaskService:
         description: Optional[str] = None,
         actor: Optional[str],
     ) -> TaskRecord:
+        """创建顶级任务并写入初始历史记录。"""
+
         async with self._lock:
             async with aiosqlite.connect(self.db_path) as db:
                 db.row_factory = aiosqlite.Row
@@ -473,6 +483,8 @@ class TaskService:
         include_archived: bool = False,
         exclude_statuses: Optional[Sequence[str]] = None,
     ) -> List[TaskRecord]:
+        """按条件查询任务列表，支持分页与状态过滤。"""
+
         query = [
             "SELECT * FROM tasks WHERE project_slug = ?",
         ]
@@ -544,6 +556,8 @@ class TaskService:
         return [self._row_to_task(row, context="search") for row in rows], pages, total
 
     async def get_task(self, task_id: str) -> Optional[TaskRecord]:
+        """根据任务 ID 返回任务详情，不存在时返回 None。"""
+
         canonical_task_id = self._canonical_task_id(task_id)
         if not canonical_task_id:
             return None
@@ -574,6 +588,8 @@ class TaskService:
         description: Optional[str] = None,
         archived: Optional[bool] = None,
     ) -> TaskRecord:
+        """更新任务字段并记录历史，返回最新任务。"""
+
         canonical_task_id = self._canonical_task_id(task_id)
         if not canonical_task_id:
             raise ValueError("任务不存在")
@@ -671,6 +687,8 @@ class TaskService:
         content: str,
         actor: Optional[str],
     ) -> TaskNoteRecord:
+        """为任务追加备注，并同步写入历史记录。"""
+
         canonical_task_id = self._canonical_task_id(task_id)
         if not canonical_task_id:
             raise ValueError("任务不存在")
@@ -720,6 +738,8 @@ class TaskService:
         )
 
     async def list_notes(self, task_id: str) -> List[TaskNoteRecord]:
+        """列出指定任务的所有备注，按时间升序排列。"""
+
         canonical_task_id = self._canonical_task_id(task_id)
         if not canonical_task_id:
             return []
@@ -746,6 +766,8 @@ class TaskService:
         ]
 
     async def list_history(self, task_id: str) -> List[TaskHistoryRecord]:
+        """返回任务的历史记录列表。"""
+
         canonical_task_id = self._canonical_task_id(task_id)
         if not canonical_task_id:
             return []
@@ -828,6 +850,8 @@ class TaskService:
                 await db.commit()
 
     async def delete_task(self, task_id: str, *, actor: Optional[str]) -> TaskRecord:
+        """通过归档标记实现逻辑删除，并返回最新任务状态。"""
+
         updated = await self.update_task(task_id, actor=actor, archived=True)
         return updated
 
@@ -839,6 +863,8 @@ class TaskService:
         page_size: int = DEFAULT_LIMIT,
         exclude_statuses: Optional[Sequence[str]] = None,
     ) -> Tuple[List[TaskRecord], int]:
+        """基于页码拉取任务列表，并返回总页数。"""
+
         total = await self.count_tasks(
             status=status,
             include_archived=False,
@@ -861,6 +887,8 @@ class TaskService:
         include_archived: bool,
         exclude_statuses: Optional[Sequence[str]] = None,
     ) -> int:
+        """统计满足条件的任务数量，用于分页。"""
+
         query = "SELECT COUNT(1) AS c FROM tasks WHERE project_slug = ?"
         params: List[object] = [self.project_slug]
         if not include_archived:
@@ -880,6 +908,8 @@ class TaskService:
         return int(row["c"] if row else 0)
 
     async def backup(self, target_path: Path) -> None:
+        """将当前数据库备份到指定路径。"""
+
         target_path = target_path.expanduser()
         target_path.parent.mkdir(parents=True, exist_ok=True)
         async with self._lock:
@@ -907,6 +937,8 @@ class TaskService:
         return token
 
     def _canonical_task_id(self, value: Optional[str]) -> Optional[str]:
+        """将外部传入的任务 ID 规范化为统一格式。"""
+
         if value is None:
             return None
         token = value.strip()
@@ -916,6 +948,8 @@ class TaskService:
         return self._convert_task_id_token(token)
 
     def _write_id_migration_report(self, mapping: Dict[str, str]) -> None:
+        """将任务 ID 迁移结果记录为 JSON 报告，便于排查。"""
+
         if not mapping:
             return
         try:
@@ -941,6 +975,8 @@ class TaskService:
             )
 
     async def _fetch_task_row(self, db: aiosqlite.Connection, task_id: str):
+        """从数据库查询指定任务的原始行。"""
+
         canonical_task_id = self._canonical_task_id(task_id)
         if not canonical_task_id:
             return None
@@ -952,6 +988,8 @@ class TaskService:
             return await cursor.fetchone()
 
     async def _next_root_sequence(self, db: aiosqlite.Connection) -> int:
+        """自增并返回 root 任务序列号。"""
+
         async with db.execute(
             "SELECT last_root FROM task_sequences WHERE project_slug = ?",
             (self.project_slug,),
@@ -984,6 +1022,8 @@ class TaskService:
         payload: Optional[str] = None,
         created_at: Optional[str] = None,
     ) -> None:
+        """写入任务历史记录，自动补齐时间戳。"""
+
         normalized = ensure_shanghai_iso(created_at) if created_at else None
         timestamp = normalized or shanghai_now_iso()
         await db.execute(
@@ -1034,6 +1074,8 @@ class TaskService:
         *,
         context: str,
     ) -> TaskRecord:
+        """将 sqlite row 转换为 TaskRecord 实例。"""
+
         tags_raw = row["tags"] or "[]"
         try:
             tags_data = tuple(json.loads(tags_raw))
