@@ -447,6 +447,98 @@ def test_delete_flow_fallbacks_to_original_slug(repo: ProjectRepository, tmp_pat
     assert repo.get_by_bot_name(record.bot_name) is None
 
 
+def test_get_project_runtime_state_handles_casefold(repo: ProjectRepository, tmp_path: Path):
+    """确保辅助函数能兼容大小写差异并返回同一状态实例。"""
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+
+    # slug 大小写不同仍应命中
+    runtime_state_upper = master._get_project_runtime_state(manager, "SAMPLE")
+    runtime_state_lower = master._get_project_runtime_state(manager, "sample")
+    assert runtime_state_upper is runtime_state_lower
+    assert runtime_state_upper.status == "stopped"
+
+    # 不存在的 slug 返回 None
+    runtime_state_none = master._get_project_runtime_state(manager, "not-found")
+    assert runtime_state_none is None
+
+
+def test_on_project_action_delete_starts_confirmation_flow(repo: ProjectRepository, tmp_path: Path):
+    """模拟按钮点击，验证删除流程可以正确进入确认状态。"""
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    storage, fsm_state = _build_fsm_state()
+    callback = DummyCallback("project:delete:sample")
+
+    async def _invoke():
+        await master.on_project_action(callback, fsm_state)
+
+    asyncio.run(_invoke())
+    state_value = asyncio.run(fsm_state.get_state())
+    assert state_value == master.ProjectDeleteStates.confirming.state
+    assert callback.message._answers, "应提示用户确认删除"
+    answer_text, _ = callback.message._answers[-1]
+    assert "确认删除项目" in answer_text
+
+
+def test_on_project_action_delete_blocks_when_running(repo: ProjectRepository, tmp_path: Path):
+    """worker 运行中时应拒绝删除请求。"""
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    manager.state_store.data["sample"].status = "running"
+    storage, fsm_state = _build_fsm_state()
+    callback = DummyCallback("project:delete:sample")
+
+    async def _invoke():
+        await master.on_project_action(callback, fsm_state)
+
+    asyncio.run(_invoke())
+    assert callback._answers[-1] == ("请先停止该项目的 worker 后再删除。", True)
+    assert not callback.message._answers
+    assert asyncio.run(fsm_state.get_state()) is None
+
+
+def test_on_project_action_delete_unknown_slug(repo: ProjectRepository, tmp_path: Path):
+    """未知项目 slug 应立即返回提示。"""
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    storage, fsm_state = _build_fsm_state()
+    callback = DummyCallback("project:delete:missing")
+
+    async def _invoke():
+        await master.on_project_action(callback, fsm_state)
+
+    asyncio.run(_invoke())
+    assert callback._answers[-1] == ("未知项目", True)
+    assert asyncio.run(fsm_state.get_state()) is None
+
+
+def test_on_project_action_delete_repeated_request(repo: ProjectRepository, tmp_path: Path):
+    """重复点击删除按钮时应提示流程已存在，避免重复覆盖 FSM。"""
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    storage, fsm_state = _build_fsm_state()
+    first_callback = DummyCallback("project:delete:sample")
+
+    async def _first():
+        await master.on_project_action(first_callback, fsm_state)
+
+    asyncio.run(_first())
+    # 第二次点击
+    second_callback = DummyCallback("project:delete:sample")
+
+    async def _second():
+        await master.on_project_action(second_callback, fsm_state)
+
+    asyncio.run(_second())
+    assert second_callback._answers[-1] == ("当前删除流程已在确认中，请使用按钮完成操作。", True)
+
+
 def test_projects_overview_hides_create_button(repo: ProjectRepository, tmp_path: Path):
     manager = _build_manager(repo, tmp_path)
     text, markup = master._projects_overview(manager)
