@@ -1,6 +1,7 @@
 import asyncio
 import json
 import os
+import sys
 import time
 from pathlib import Path
 from types import SimpleNamespace
@@ -14,6 +15,10 @@ from aiogram.fsm.storage.base import StorageKey
 from aiogram.fsm.storage.memory import MemoryStorage
 from aiogram.types import InlineKeyboardMarkup, ReplyKeyboardMarkup
 
+ROOT = Path(__file__).resolve().parents[1]
+if str(ROOT) not in sys.path:
+    sys.path.insert(0, str(ROOT))
+
 os.environ.setdefault("BOT_TOKEN", "TEST_TOKEN")
 
 import bot
@@ -758,6 +763,7 @@ def test_bug_report_auto_push_success(monkeypatch, tmp_path: Path):
         reply_to,
         supplement: Optional[str],
         actor: Optional[str],
+        is_bug_report: bool | None = None,
     ):
         assert reply_to is message
         push_calls.append((chat_id, supplement, actor))
@@ -1095,7 +1101,7 @@ def test_task_summary_command_triggers_request(monkeypatch, tmp_path: Path):
     assert dispatch_calls, "应向模型推送摘要请求"
     prompt_text = dispatch_calls[0][1]
     assert prompt_text.startswith(
-        "进入摘要阶段...\n任务编码：/TASK\\_0200\nSUMMARY_REQUEST_ID::"
+        "进入摘要阶段...\n任务编码：/TASK_0200\nSUMMARY_REQUEST_ID::"
     )
     assert message.calls, "应向用户提示处理结果"
     reply_text, _, _, _ = message.calls[-1]
